#
# spec file for package python-pgmagick
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pgmagick
Version:        0.7.6
Release:        2.6
Summary:        Yet Another Python wrapper for GraphicsMagick
License:        MIT
URL:            https://github.com/hhatto/pgmagick/
Source:         https://files.pythonhosted.org/packages/source/p/pgmagick/pgmagick-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/hhatto/pgmagick/master/test/Makefile
Source2:        https://raw.githubusercontent.com/hhatto/pgmagick/master/test/utils.py
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  ghostscript-fonts-std
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(GraphicsMagick++)
%if 0%{?suse_version} >= 1500
BuildRequires:  libboost_python3-devel
%if %{with python2}
BuildRequires:  libboost_python-devel
%endif
%else
BuildRequires:  boost-devel
%endif
%python_subpackages

%description
The pgmagick package is a yet another boost.python based
wrapper for GraphicsMagick.

%prep
%autosetup -p1 -n pgmagick-%{version}
cp %{SOURCE1} test

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export PYTHONDONTWRITEBYTECODE=1
%python_expand cp -v %{SOURCE2} %{buildroot}%{$python_sitearch}
mv pgmagick do-not-use-pgmagick
%python_expand PYTHON=$python PYTHONPATH=%{buildroot}%{$python_sitearch} make -C test all clean
mv do-not-use-pgmagick pgmagick
%python_expand rm -v %{buildroot}%{$python_sitearch}/utils.py

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/pgmagick
%{python_sitearch}/pgmagick-%{version}.dist-info

%changelog
* Thu Mar 21 2024 Steve Kowalik <steven.kowalik@suse.com>
- Rewrite the check section completly, making use of upstream's Makefile.
- Also copy in a missing utils with a constant when we require it.
- Switch to pyproject macros.
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.6:
  * #70, #67 : Support M1 Mac
- update to 0.7.5:
  * #50 : Enable passing Py3 bytes as pixels for constructor with
    StorageType
  * #51 : Fix screwed parameters
- update to 0.7.4:
  * fix libboost_python filename for macOSX environment with
    Homebrew. ( 8ad8f917e93ba66c49d01952ba5488cd473a4fc4 )
  * `setup.py` now looks for `libboost_python2x`,
    `libboost_python2x-mt`, `libboost_python3x` and
    `libboost_python3x-mt` as well.
- drop reproducible.patch (upstream)
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix building without python2
* Mon Jun 24 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort dir entries (boo#1041090)
* Thu May 10 2018 toddrme2178@gmail.com
- Fix boost dependency
* Thu May 10 2018 toddrme2178@gmail.com
- Update to version 0.7.4
  * fix libboost_python filename for macOSX environment with
    Homebrew. ( 8ad8f91 )
    setup.py now looks for libboost_python2x, libboost_python2x-mt,
    libboost_python3x and libboost_python3x-mt as well.
- Use license tag
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update to version 0.7.2
  + No changelog available
* Sun Jan 21 2018 toddrme2178@gmail.com
- Fix dependencies on new versions of openSUSE
* Mon Aug 28 2017 toddrme2178@gmail.com
- Update to version 0.6.6
  + No changelog available
- Implement single-spec version
- Fix source URL
* Thu Sep  3 2015 toddrme2178@gmail.com
- Update to version 0.5.11
  + No changelog available
* Wed Dec  4 2013 p.drouand@gmail.com
- Update to version 0.5.7
  + No changelog available
- Remove SLE11 relative stuff; package doesn't build for it
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri May 25 2012 toddrme2178@gmail.com
- Add python 3 package
- Spec file cleanups
- Update to version 0.5.1
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 0.4.2
* Sat Jan 29 2011 alexandre@exatati.com.br
- Initial packages (3.2) for openSUSE.
